import ast
import os
import re

from setuptools import setup

root = os.path.abspath(".")
with open(os.path.join(root, "README.rst"), "rt") as f:
    README = f.read()

_version_re = re.compile(r"__version__\s*=\s*(.*)")
with open(os.path.join(root, "BotUtils", "__init__.py"), "rb") as f:
    version = str(
        ast.literal_eval(_version_re.search(f.read().decode("utf-8")).group(1))
    )

extras = {
    "asyncpraw": ["asyncpraw"],
    "postgres": ["psycopg2-binary"],
    "tunnel": ["sshtunnel"],
    "sqla": ["sqlalchemy"],
    "lint": [
        "black",
        "docstrfmt",
        "flake8",
        "flynt",
        "isort",
        "pydocstyle",
    ],
}
extras["dev"] = extras["lint"] + extras["sqla"] + extras["tunnel"]

setup(
    name="BotUtils",
    author="Lil_SpazJoekp",
    author_email="lilspazjoekp@gmail.com",
    description="Personal Utilities for Spaz's bots",
    license="Private",
    version=version,
    install_requires=[
        "colorlog",
        "credmgr",
        "praw",
        "sentry_sdk; sys_platform != 'darwin'",
    ],
    packages=["BotUtils"],
    extras_require=extras,
)
